# binaryconv.py
The goddamn best binary converter for Python 3*.

```
>>> import binaryconv.convertbin
>>> binaryconv.convertbin.text_to_bits('Hello')
'0100100001100101011011000110110001101111'
>>> binaryconv.convertbin.text_from_bits('0100100001100101011011000110110001101111')
'Hello'
>>> 
```

Works well, not even replys a binary string.

Multiple encoding also is supported.


*only because we have no competion
